{ inputs, outputs, lib, pkgs, ... }:
{
  imports = [
    inputs.sops-nix.homeManagerModules.sops
    ../../features/direnv.nix
    ../../features/git.nix
    ../../features/vim.nix
    ../../features/fish.nix
  ] ++ (builtins.attrValues outputs.homeManagerModules);
  
  sops.age.sshKeyPaths = ["/etc/ssh/ssh_host_ed25519_key"];
  sops.defaultSopsFile = ../../../secrets/default.yaml;

  nixpkgs = {
    overlays = [
      outputs.overlays.additions
      outputs.overlays.modifications
      outputs.overlays.unstable-packages
      #inputs.nur.overlay
    ];
    config = {
      allowUnfree = true;
      allowUnfreePredicate = (_: true);
    };
  };

  home = {
    sessionVariables = {
      EDITOR = "nvim";
      TERMINAL = lib.mkDefault "kitty";
      COLORTERM = lib.mkDefault "truecolor";
      BROWSER = lib.mkDefault "firefox";
    };

    packages = with pkgs; [
      w3m
    ];
  };
  
  programs.home-manager.enable = true;  

  home.stateVersion = "24.05";
}
